@@ -108,12 +108,6 @@ HISTORY
 
 long totalerr, totalwrn;
 
-#ifdef STANDALONE
-#include "fitsverify.c"
-#else
-#include "headas_main.c"
-#endif
-
 /* Function Prototypes */
 int ftverify (void);
 int ftverify_getpar (char *infile, char *outfile,int * prehead,
@@ -123,6 +117,12 @@ int ftverify_work (char *infile, char *outfile,int prehead,
     int prstat, char* errreport, int testdata, int testcsum,
     int testfill, int heasarc_conv);
 
+#ifdef STANDALONE
+#include "fitsverify.c"
+#else
+#include "headas_main.c"
+#endif
+
 int err_report=0;
 int prhead=0;
 int prstat=1;
@@ -242,12 +242,16 @@ int ftverify_work(
 /* call work function to verify that infile conforms to the FITS
        standard and write report to the output file */
 {
+#ifdef WEBTOOL
     FILE *runfile = 0;
+    int runnum;
+    char runchars[30];
+#endif
     FILE *outfptr = 0;
     FILE *list=0;
-    int status = 0, vfstatus = 0, filestatus, runnum;
+    int status = 0, vfstatus = 0, filestatus;
     char * p;
-    char task[80],runchars[30];
+    char task[80];
     char tversion[80];
     float fversion;
     int i, nerrs, nwarns;
