@@ -2771,7 +2771,8 @@ void   parse_vtform(fitsfile *infits,
                 FitsHdu *hduptr, 
 		int colnum,		/* column number */
 		int* datacode,		/* data code */
-		long* maxlen		/* maximum length of the vector */
+		long* maxlen,		/* maximum length of the vector */
+                int* isQFormat          /* true if var col is 'Q' format */
                ) 
 { 
     int i = 0; 
@@ -2796,7 +2797,8 @@ void   parse_vtform(fitsfile *infits,
 	  "TFORM%d is not for the variable length array: %s.", 
         colnum, tform[colnum-1]); 
         wrterr(out,errmes,1);
-    } 
+    }
+    *isQFormat = (*p == 'Q') ? 1 : 0;
 
     fits_get_coltype(infits,colnum, datacode, NULL, NULL, &status); 
     status = 0;
